Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(710)

Unified Diff: net/base/network_change_notifier_win.h

Issue 10873018: [net] Move DnsConfigService to NetworkChangeNotifier. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix null-dereference Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/network_change_notifier_win.h
diff --git a/net/base/network_change_notifier_win.h b/net/base/network_change_notifier_win.h
index c6a74155724cebdd643e8bdfe649d20b11789235..f2d3d9928a03bbe6547beb356a9d8495902aba28 100644
--- a/net/base/network_change_notifier_win.h
+++ b/net/base/network_change_notifier_win.h
@@ -47,7 +47,7 @@ class NET_EXPORT_PRIVATE NetworkChangeNotifierWin
int sequential_failures() { return sequential_failures_; }
private:
- class DnsWatcherThread;
+ class DnsConfigServiceThread;
friend class NetworkChangeNotifierWinTest;
// NetworkChangeNotifier methods:
@@ -90,8 +90,8 @@ class NET_EXPORT_PRIVATE NetworkChangeNotifierWin
// Used for calling WatchForAddressChange again on failure.
base::WeakPtrFactory<NetworkChangeNotifierWin> weak_factory_;
- // Thread on which we can run DnsConfigWatcher.
- scoped_ptr<DnsWatcherThread> dns_watcher_thread_;
+ // Thread on which we can run DnsConfigService.
+ scoped_ptr<DnsConfigServiceThread> dns_config_service_thread_;
DISALLOW_COPY_AND_ASSIGN(NetworkChangeNotifierWin);
};

Powered by Google App Engine
This is Rietveld 408576698